@@ -181,7 +181,7 @@ class QCticQasmSimulator(BaseQCticSimulator):
             QasmBackendConfiguration: The configuration object.
         """
 
-        conf = copy.deepcopy(QasmSimulator.DEFAULT_CONFIGURATION)
+        conf = copy.deepcopy(QasmSimulator().configuration().to_dict())
         conf.update(cls.BASE_CONFIGURATION)
 
         conf.update({
@@ -207,7 +207,7 @@ class QCticStatevectorSimulator(BaseQCticSimulator):
             QasmBackendConfiguration: The configuration object.
         """
 
-        conf = copy.deepcopy(StatevectorSimulator.DEFAULT_CONFIGURATION)
+        conf = copy.deepcopy(StatevectorSimulator().configuration().to_dict())
         conf.update(cls.BASE_CONFIGURATION)
 
         conf.update({
@@ -233,7 +233,7 @@ class QCticUnitarySimulator(BaseQCticSimulator):
             QasmBackendConfiguration: The configuration object.
         """
 
-        conf = copy.deepcopy(UnitarySimulator.DEFAULT_CONFIGURATION)
+        conf = copy.deepcopy(UnitarySimulator().configuration().to_dict())
         conf.update(cls.BASE_CONFIGURATION)
 
         conf.update({
