@@ -1,7 +1,7 @@
 import datetime
 
-from marshmallow import (Schema, ValidationError, fields, post_load, pre_dump,
-                         pre_load, validate, validates_schema)
+from marshmallow import (INCLUDE, Schema, ValidationError, fields, post_load,
+                         pre_dump, pre_load, validate, validates_schema)
 from qiskit.providers import JobStatus
 from qiskit.qobj import QasmQobj as Qobj
 from qiskit.result import Result
@@ -19,6 +19,9 @@ def _qiskit_model_validator(klass):
 
 
 class GetJobsQuerySchema(Schema):
+    class Meta:
+        unknown = INCLUDE
+
     limit = fields.Integer(
         default=10,
         required=True,
@@ -53,6 +56,9 @@ class GetJobsQuerySchema(Schema):
 
 
 class JobSchema(Schema):
+    class Meta:
+        unknown = INCLUDE
+
     job_id = fields.Str(required=True)
 
     date_submit = fields.AwareDateTime(
@@ -98,5 +104,8 @@ class JobSchema(Schema):
 
 
 class BackendStatusSchema(Schema):
+    class Meta:
+        unknown = INCLUDE
+
     operational = fields.Boolean(required=True)
     pending_jobs = fields.Integer(required=True)
