@@ -5,15 +5,16 @@ import json
 import random
 import warnings
 
+import numpy
 import pytest
+from qctic.backend import (QCticQasmSimulator, QCticStatevectorSimulator,
+                           QCticUnitarySimulator)
 from qiskit import Aer, QuantumCircuit, execute
 from qiskit.assembler import disassemble
 from qiskit.providers import JobStatus
 from qiskit.qobj import QasmQobj as Qobj
 from werkzeug.wrappers import Response
 
-from qctic.backend import (QCticQasmSimulator, QCticStatevectorSimulator,
-                           QCticUnitarySimulator)
 from tests.utils import fake_circuit
 
 _JOB_REMOTE = {
@@ -53,6 +54,9 @@ def _execute_job(req, aer_backend, assert_func=None):
             "execute_kwargs": execute_kwargs
         })
 
+    backend_options = execute_kwargs.pop("backend_options", {})
+    execute_kwargs.update(backend_options)
+
     aer_job = execute(circuits[0], aer_backend, **execute_kwargs)
 
     return aer_job.result()
@@ -72,6 +76,19 @@ def _handler_create_job(backend_name, job_dict, assert_func=None):
     return handler
 
 
+class QobjEncoder(json.JSONEncoder):
+    def default(self, obj):
+        if isinstance(obj, numpy.ndarray):
+            return obj.tolist()
+        if isinstance(obj, complex):
+            return (obj.real, obj.imag)
+        return json.JSONEncoder.default(self, obj)
+
+
+def _safe_qobj_dict(item):
+    return json.loads(json.dumps(item, cls=QobjEncoder))
+
+
 def _handler_get_job(job, job_dict):
     def handler(req):
         job_dict.update({
@@ -79,6 +96,8 @@ def _handler_get_job(job, job_dict):
             "job_id": job.job_id()
         })
 
+        job_dict.update(_safe_qobj_dict(job_dict))
+
         return Response(json.dumps(job_dict))
 
     return handler
