@@ -32,6 +32,7 @@ def fake_job_dict():
         "qobj": qobj.to_dict(),
         "status": random.choice([
             JobStatus.INITIALIZING.name,
-            JobStatus.RUNNING.name
+            JobStatus.RUNNING.name,
+            JobStatus.QUEUED.name
         ])
     }
